from .__pytransform import pyarmor_runtime

"""
# MixtureMapping

[![Documentation](https://github.com/VK/dash-express-components/workflows/Publish%20release/badge.svg)](https://vk.github.io/mixturemapping-doc)
[![PyPI version](https://badge.fury.io/py/mixturemapping.svg)](https://badge.fury.io/py/mixturemapping)

Train Gaussian Mixture Mappings


## Provides:
  1. Layers to build tensorflow models to map Gaussian mixtures
  2. Tools to compute yield values of Gaussian mixtures in complex binning schemes

## Example
  
    import mixturemapping as mm  
    import tensorflow as tf

    inMeans = tf.keras.Input(shape=(mixN, inputMixM), name="Means", dtype=dataType)
    inStdDevs = tf.keras.Input(shape=(mixN, inputMixM), name="StdDevs", dtype=dataType)
    inWeight = tf.keras.Input(shape=(mixN), name="Weights", dtype=dataType)

    mapModel = tf.keras.Sequential()
    mapModel.add( tf.keras.layers.Dense(40, activation="relu", kernel_regularizer=regularizers.l2(0.001)) )
    mapModel.add( tf.keras.layers.Dense(40, activation="relu", kernel_regularizer=regularizers.l2(0.001)) )
    mapModel.add( tf.keras.layers.Dense(outputMixM))
    y = mapModel(inMeans)

    deltaModel = tf.keras.Sequential()
    deltaModel.add( tf.keras.layers.Dense(40, activation="relu", kernel_regularizer=regularizers.l2(0.001)) )
    deltaModel.add( tf.keras.layers.Dense(40, activation="relu", kernel_regularizer=regularizers.l2(0.001)) )
    deltaModel.add( tf.keras.layers.Dense(outputMixM))
    yDelta = deltaModel(inMeans)

    covALayer = mm.layers.TrainableCovMatrix(outputMixM, name="CovA")
    covA = covALayer(inMeans)

    mapLayer = mm.layers.GeneralMapping(outputMixM, name="Mapping", dtype=dataType)
    newDist = mapLayer({'means': inMeans, 'y':y, 'yDelta':yDelta, 'stdDevs': inStdDevs, 'weights': inWeight, 'covA': covA})

    distLayer = mm.layers.Distribution(dtype=dataType, regularize_cov_epsilon=0.95)
    dist = distLayer(newDist)

### Developement
```
$ py -m venv env
$ .\env\Scripts\activate
$ pip install -r requirements.txt
```


"""


pyarmor_runtime()
__pyarmor__(__name__, __file__, b'\x50\x59\x41\x52\x4d\x4f\x52\x00\x00\x03\x07\x00\x42\x0d\x0d\x0a\x08\x2d\xa0\x01\x00\x00\x00\x00\x01\x00\x00\x00\x40\x00\x00\x00\x87\x08\x00\x00\x00\x00\x00\x18\xc8\x84\x64\x37\x4f\x42\x0e\x09\x29\xdc\x9b\x0d\x2a\xce\x39\x28\x00\x00\x00\x00\x00\x00\x00\x00\x6b\x69\x85\x75\x8c\xea\x39\xa9\xc0\x5d\x0b\x39\x49\xdf\xbd\x02\xf3\x91\x61\xef\x96\x12\x62\x04\x2c\x5e\x45\x9a\x08\xc6\x3e\xc6\x6b\xd9\x00\x44\xfd\x4b\xd6\x2f\x50\xbb\x9c\x12\x2b\xbc\x57\x3d\x3a\xed\x0b\xcf\x27\x77\x5e\xef\x66\x2e\x71\x6c\xe6\x58\x91\xdf\xc4\xc3\x39\x7b\xa2\x0b\x0e\x75\xb3\xb1\x01\x5b\x19\x1e\xbd\x12\x70\xf6\xfa\x47\xf7\x7a\xe9\x8d\xbe\xfc\x03\xef\xde\x74\x25\x0b\x75\x20\xa3\xb0\x99\xfc\x6b\x0f\x15\xcb\x23\x72\xab\x93\x5e\xb3\xb2\x41\x73\xd2\x14\x24\x66\x57\x7b\xfd\xea\x51\xbf\x33\xa7\x9f\x70\xa1\x9c\xb3\x29\x87\x71\x1c\x14\x55\xfd\x63\x67\xc1\xc3\xa7\xde\x4c\x98\x84\xd3\x16\x04\x2c\xf3\x5a\x08\xb1\x4b\x2d\x62\xb8\x94\x94\xf5\x06\x92\x82\x9f\x03\x13\x2e\xc9\xbc\x51\x91\xec\x19\x05\x85\x89\x14\xdd\xc2\xb4\x59\x2e\x39\x0c\x68\x91\x38\x41\xb1\xbd\x6e\xa1\x08\x58\x98\x24\xed\x54\xdd\xcd\x4d\x70\x45\x9a\x17\x35\xfe\xc5\x7f\xdc\x69\xd0\xf3\x25\xb6\x0b\x2f\xe8\xce\x19\x88\x6f\xd8\xfb\xfa\xd4\x41\x91\x1e\xbe\xb2\xb1\x1e\x0d\x37\x72\xe5\x3a\x2f\xfb\x81\x25\x5e\x56\x1a\x83\xc8\xe6\xff\xd2\x58\x24\xf0\x4e\xe3\x87\x8c\xd4\x02\x5e\x95\x52\x63\x5b\x70\x5c\x2d\x9f\xe0\x59\x5f\xa7\x2b\x3e\x96\x28\xc8\xf1\xc7\xb8\x85\x78\xc2\x8d\x7a\x9c\x0d\xbb\x4b\x33\xdc\x0f\xb7\xba\xc9\xe1\xd2\x91\xd5\x42\xfa\xd3\xa9\x95\xaa\xe2\x56\xb0\x48\x60\xbc\xf1\x46\x7c\xa4\x3b\x37\x87\x00\x12\xab\x31\x41\x3a\xa4\xc7\xf4\xbc\x30\x83\xbb\xfc\x8f\x71\x5e\x17\xed\x3b\xff\xcb\xec\xaa\x8d\xe5\x16\x9f\x40\xc9\xdb\xa0\x70\x5b\xf4\xf0\xec\xae\x15\x45\xf1\xc7\xd0\x7c\x09\x3b\xd4\x88\x75\x12\xb5\xaf\xeb\xbf\x5c\xff\x1b\xb9\x13\x0b\xbe\xaf\x07\xeb\x74\x4c\xa8\xa3\x88\x2a\x2f\x97\xbb\x9b\xa2\x30\xd2\x7d\x37\x14\x8a\xa8\xd4\xfa\x97\xfe\x3f\x95\x04\xb5\x04\x3b\x5a\x9c\xb1\x3a\x2a\x4a\x2d\x52\xec\x08\x8d\x7b\xf4\x02\x09\x97\x40\x8d\xde\x1b\xcd\xaa\x0d\x50\xf2\x85\x9c\x1a\xdd\x82\xde\x8a\xf9\x59\x09\x18\x28\x87\xa0\xd9\x4c\x18\x7f\xb6\x08\x5e\x29\x6e\x94\xd3\xea\xbf\xb1\x19\xd0\x7d\xf5\x28\xab\x0d\xeb\x27\x99\x01\x27\xba\x46\x05\xae\x75\x43\xb4\x46\xd1\x39\x63\x1b\x7a\x19\x6e\xae\xd7\x6c\xf0\x1e\x42\x5a\xbb\x2e\x6f\x77\x0f\xe8\x07\x96\x7e\xe4\xb3\x26\x60\x62\x4a\x9e\xff\x02\x5d\x1b\xe6\x3f\x4c\xee\x96\x79\x42\xfe\xc3\x24\xa5\x8e\xa8\xfe\x36\xf8\xd6\x6f\x32\x6e\x41\xaf\xa6\x24\xc6\xfe\x21\x84\x9a\x58\x3f\xe9\x87\x9c\x9f\x5b\x5b\x69\x98\xa8\x6b\x94\x0b\x10\xb0\x04\x3b\xd9\x22\x4b\x53\x2d\x04\x10\xd7\x6f\xdc\xf4\x7d\x4b\xb9\x8c\x35\xf2\xaa\x2d\x07\x64\x22\xb6\x08\xc7\xb8\x69\x0c\x09\xf1\x3b\x03\x45\x1b\x54\xad\x99\xfe\xcb\x8d\x1a\x14\x76\x4e\xb8\xb5\x59\xf2\xf9\x10\xd2\x25\xd6\x7d\x8b\xb7\x80\x18\xab\xb0\x04\xab\x3f\x41\xbe\xe1\x69\xa2\x0b\x59\x62\x54\xb1\xbe\x2b\xc3\xf2\x21\xef\xe1\x9b\x0d\xf2\xe3\x11\x23\x14\x1d\x4b\xea\x2b\xed\x53\x60\xd2\xb2\x02\x6f\xbc\x8a\x76\xd4\x0e\x0d\x58\xaf\x5d\xec\x1d\xe7\xc5\x05\xae\x14\x53\xd7\x73\x37\xa8\xa4\x2a\x07\xc6\x58\x34\x41\xc9\xe9\xe8\x23\x05\x8d\x4f\xce\x7a\x41\xdb\x96\xa7\x14\x69\x64\xd6\x07\x61\x06\xe6\xda\x45\xe5\xe4\xb7\xc7\x98\xb7\x52\x31\x88\xc9\x49\x9e\x26\xc2\x83\x72\xf9\x24\x3d\x59\x2b\x04\xfd\x49\xb7\xd1\x1c\x5c\x9f\x30\xec\x8d\xca\xa0\x54\x6e\xed\xc0\xa4\x2f\xda\x1e\x8d\xbb\x03\x57\x09\x4f\xd4\x7b\x8d\x1e\x69\x64\xe5\x31\x37\xd5\x84\x98\x9f\x21\x97\x9a\x98\x51\x66\x25\xb7\x14\xf0\xca\xd6\xe4\x61\x64\xb5\xd4\xc8\x2e\x81\x5f\x58\x50\xde\xe5\xa5\xdc\x74\x1d\xaf\xbf\xbe\x66\x44\x53\x56\x8d\x8c\xb3\x46\xc5\xec\xff\x0d\x70\x9f\xfb\xc4\xc5\xe3\xe6\xdf\x33\xa1\xa7\x9a\x06\xd8\xb4\x98\x4a\xe7\x3b\x6f\xeb\x7d\x59\x06\xae\x66\x1a\x37\xfa\x3d\xf7\x32\xe8\x59\xee\x5a\xe5\xc0\x5c\x10\x9c\x9f\x3d\xfb\xe2\xef\x16\x96\xb4\x07\xc0\x35\x60\xb3\x2f\x05\x9f\x28\x6d\x2e\x13\x94\x2c\xe0\x3c\x6b\xb7\x7a\x55\x66\x67\xfc\x84\x48\x14\x31\x05\xa4\x31\x5b\x07\x53\xbf\x02\xcf\xc9\x34\xc0\xf9\x45\x5c\xe1\x64\x3b\xbb\x89\x0a\x3a\x93\x4b\x80\x3c\x95\x4f\xf2\x5a\x53\x40\x7a\xd4\x52\x09\x32\x0e\x79\xda\x74\xb1\x7a\xc6\x38\x0e\x5d\x33\xa1\x9e\x4b\x8d\xf2\xc5\x3d\x4a\x8d\x32\x2f\x66\xbc\x62\xe9\x86\xac\xdf\x26\x8a\xfb\x6e\xcb\x7f\xb7\xb7\x72\x18\x71\xa4\x69\x15\xac\xcf\xd5\xab\xc7\xfd\x6f\x60\x66\xc9\xee\x58\x9b\x8f\xce\x69\x9c\x0b\xdf\xa4\x34\xf9\x51\xe0\x91\x86\x1c\x91\xfb\x07\xa1\x1e\x71\xe7\x79\xc7\x69\xfd\x92\x28\xc2\x7a\x1a\xce\x9d\x54\xfc\xe2\x7a\x12\x31\xe1\xa5\xf7\x65\x51\xbf\x48\xe9\x11\xde\xfa\xc5\xaf\x17\x0f\x79\xc5\x42\x72\xd3\xbe\xb6\xcc\xb5\x11\xc8\xc5\x4d\xc5\x3b\xe7\x03\xbb\xec\x6d\x70\xe8\x60\xd9\x03\xc7\xb1\x56\x26\x2d\x70\x42\x37\x1a\xfb\x4d\x9a\x00\x6a\x85\x40\xbd\xaf\xf0\xa3\xe5\x34\x58\x3c\x02\x8a\x60\x39\x24\xc3\xf4\xc8\x78\x28\xb3\x86\x91\x6e\x50\xb8\x4a\xdc\xa2\x82\xd7\x6e\x30\xf6\x4a\x82\x75\xd7\xc2\xea\xb3\xea\x07\x88\x9e\x9e\x47\xa1\x1d\xc7\x43\x6c\x49\x46\x3c\x2b\x45\x3d\x5b\xb1\x82\xc9\xc3\xa7\x27\xdc\x60\x40\x5c\x0c\x26\xce\xbe\x33\x4a\x77\xe7\x2b\x06\x29\x39\x12\xab\xe9\x55\xe0\xbb\xf9\xb0\x98\x70\x1c\x8b\xcb\x1a\x27\xc5\xaa\x41\x9d\xc1\xc2\xc1\xd0\x78\xca\x5c\x90\x02\x2c\xa6\xe7\x3a\x2f\xc4\x30\xf9\x60\x53\x22\xe2\xeb\x51\x54\x44\xf9\x31\xa4\x16\x73\x1e\x43\xc2\x5a\xdb\xe6\xe1\x67\x54\x37\x20\x2c\xaa\x50\x1b\xff\x6b\x8b\x08\xdd\x54\xa6\xd9\x04\xd4\x44\xc5\x26\xca\xe7\xce\x20\xf9\xd2\xa1\x42\x61\xf2\x15\x7d\x3c\xdc\xb9\xf2\x25\xad\xeb\x5c\x50\xbb\xae\x14\xd5\x69\x02\xc7\xdf\x14\x0a\x08\xa7\xdc\x49\x94\xa8\xdf\x2a\xd0\x7c\x54\xec\x00\xa5\xb6\xd2\x73\x2b\x6a\xe1\x34\x4f\x2f\x65\xbb\x51\xb0\xe2\x6f\xc4\x56\x33\xdb\x3c\x04\x7f\xba\x52\xb4\x2f\xb1\xca\x2b\x89\xe6\xbf\xfc\xc7\x6a\x72\xca\x19\x5b\x59\x29\x27\x06\x2b\x83\xd2\xab\xf8\x23\x2b\xd3\x87\xba\x91\x3a\xbd\xc0\x77\xc7\x12\x16\x30\x8d\x90\x6b\x79\x2d\xbd\xda\x59\x7b\x99\x60\x17\x5b\x9d\x12\xb5\x1a\xa9\x51\x93\x53\x9d\x3f\x12\x25\x53\xbd\x5d\x47\xc4\x3a\xfe\xaa\x77\x01\x5a\xe6\x2c\xcc\xf0\xb0\x1f\xd2\xbc\xba\x33\x7c\xc0\x7a\x87\x6c\xb2\xa4\x9e\x4d\x63\x6b\x84\xff\x71\xbe\xf3\x71\xe1\x3d\x7d\x45\xf2\x88\xf9\x95\x82\xa3\xda\x58\xa2\x7b\x17\xf9\x6d\x55\x1e\xb6\x65\x46\x22\x6d\xf0\x22\x8f\xe5\x62\x33\x59\x0c\xd0\x3d\xf6\x77\x23\x31\x38\x69\xf2\x49\x42\x8a\x39\x28\x18\xfd\x36\x07\xbc\x0b\x83\xbb\x56\x98\x51\xf8\x27\x6e\x62\x87\x27\x7f\x98\x69\x39\xae\x10\x35\x77\x35\x8d\x8f\x8a\xa3\x80\x5a\x49\x9d\x82\xf4\x50\x71\xb7\xe3\x27\x0f\xaa\x9a\xc7\x9c\xfb\x77\xb0\x22\xd0\x8b\x2b\xed\x08\x5a\x02\xc6\x30\x0d\x66\x8f\xa9\x6a\x16\xbc\x7b\xdb\x42\x89\x1a\xea\xba\x23\xb0\xfe\xb8\x43\x00\x08\x4d\x57\x8c\x78\xfb\xba\x7f\x5d\xec\x91\x25\xe9\x32\x83\x98\x14\xb2\x3e\xc8\xf2\xa8\xfe\x6d\x82\x9c\xa0\xb9\x16\xc7\x95\x75\x97\x4c\x26\x2d\x67\xb7\x5e\x26\xd1\x83\xf2\x12\xae\xb0\x7b\x17\x8e\x2d\x48\x54\x21\x3d\xee\x14\xf9\x27\x3c\x4d\xdc\x1e\x02\xc9\x5e\x20\x07\x3e\xdf\x66\x9d\x66\x6a\x3e\x07\x08\x72\xb4\x09\x28\x6d\x93\x9f\xd2\x9b\x1a\x59\x96\xd5\x7b\x0e\x08\xe8\x50\x63\x10\x85\xf6\x54\x89\x69\xe0\x05\x70\x68\xf0\xa8\x9f\xdd\x40\x78\x4c\x06\xfe\xea\x58\xf0\x31\x84\xac\xf8\xa3\x4f\x6f\x95\x23\x76\x5c\x27\x7b\x34\xc6\x24\x8a\x89\x2d\x5c\x2e\xbd\x6f\xcf\x87\x94\x82\xa1\xf0\xff\xbf\x35\x34\xe5\x41\x63\x7c\x62\xe4\x5d\x8b\x82\x17\xf3\xee\x97\x63\x43\x2d\x46\x87\xbd\x1e\xf6\x9b\x31\x07\x0b\x89\xc9\x8b\x5c\x4d\x53\x86\x41\x35\xc8\x30\x55\xeb\x93\xad\x39\x6d\x6e\x7e\x58\xe4\x9e\x95\xec\x7c\xc9\xae\x32\xbb\xf8\x74\xe2\x5a\x94\x96\x0b\xf6\xdd\x30\x2a\x71\x83\xfd\xd8\x66\x2b\x8a\xf6\xb0\xd6\x8c\x76\x5d\x9d\xed\xe8\xfd\xec\x61\x50\xca\x23\xe2\x84\x46\xe6\x1a\x48\xeb\x04\xc2\x17\x45\x3a\x36\x75\xea\x6f\xa1\x8d\x53\xa8\xc7\x6b\xc9\xe6\xa4\x6e\x78\x58\x7c\x6d\xe9\xcb\xdc\x31\x70\x5f\x8a\xab\x35\x05\x04\x4f\xce\x07\x57\xce\x0c\xfb\x83\x6f\x84\xa6\x12\xc5\x18\xa9\x8e\x79\xa8\x68\x0e\x0c\x39\x28\xd7\xc8\xbd\x42\x15\xe1\x45\x67\x93\x51\x68\xe2\xe0\x92\x01\x45\xb1\x2f\xac\xa7\x7b\xe0\xde\x4d\xc3\x81\x98\x58\xe5\x5e\x8d\xd1\xc4\x60\xed\x0f\x73\xff\xee\x7e\x36\x46\x23\x04\x7f\x82\x7e\xba\x05\x4b\xf3\x25\xf8\xcf\x91\xda\x6a\x47\x60\x82\x57\xae\xcb\xcf\x61\x00\x36\x68\x9d\xd8\x91\x63\x5d\x26\xf0\x1c\x50\xee\x23\x25\xa2\x86\xf8\xf0\x04\x21\x4c\x0c\x17\x5c\xac\x12\xac\xbb\xee\x6c\x77\xd4\xb4\xa9\x60\x8d\x48\x1b\x65\x1e\x9a\xa1\x85\xa2\xaa\x70\xc8\x3e\x66\xdf\x2f\x73\x0a\xea\x18\x22\x83\x33\x72\x08\x53\xd2\x8a\xd7\x07\xa4\x8b\x57\x31\x30\xb1\x10\x28\xc0\xcf\x35\xbf\x83\x71\x76\xce\xf3\xbf\x94\xf3\xb6\x3c\x40\xf3\xec\x97\x70\xfe\xe7\xb2\x5e\x1c\x81\x3b\x81\xa0\xfc\xa7\xc5\xac\xff\xf7\x55\x3a\x80\x96\x05\x56\x7c\xbd\xb4\x2c\xf9\x37\x51\xf7\x76\xbc\x20\xe9\x1c\xf9\x9a\xc3\x4c\x3c\x1e\x86\xe4\x69\x63\x7e\xdb\xf1\xaa\xb5\x3e\x9b\x1b\x51\x84\x63\x12\xbd\x1c\x4b\xcf\x33\xdc\x8c\x4f\x04\x78\x39\x44\x87\x7b\xdc\x00\x13\x12\x80\xbb\xe3\x4e\xd0\xc3\xca\x4e\x79\x8c\x1a\x8e\x02\xca\x0a\x45\x42\xf1\xf8\xd1\xe2\x5c\xd6\xe7\x58\x05\x88\x21\xf6\x9a\x2b\x0d\x75\x6e\x3b\x27\x71\x64\xc2\xd3\x15\x40\x91\xf1\xd3\x09\x54\x51\x60\x21\xe5\xab\xd4\x66\xae\xe1\xb6\x02\x76\x6c\xe1\xca\x13\x3a\xce\xf4\x34\x4a\x15\x1f\x28\xdb\x07\x7f\x6b\xda\xe2\x81\xb4\xae\xeb\x3f\x44\x00\xa7\x7b\x71\xc0\x46\x6f\xc1\x61\xeb\xa8\xfa\xf0\x42\x7f\x64\xf7\x11\x4f\x8a\xa2\x6d\xa8\x32\xcf\x68\x92\x9d\xb0\x19\x60\x0c', 2)

# cleanup
del pyarmor_runtime

